pub fn aroon<'a, T: ToPrimitive>(
high: &'a [T],
low: &'a [T],
window: usize,
) -> impl Iterator<Item = (f64, f64)> + 'aExpand description
Aroon
Measures the trend strength and direction of an asset based on the time between highs and lows. Consists of two lines that show the time since a recent high or low.
Usage
When up line is above the down, it suggests an uptrend.
Sources
Examples
use traquer::trend;
trend::aroon(
&[1.0,2.0,3.0,4.0,5.0,6.0,4.0,5.0],
&[1.0,2.0,3.0,4.0,5.0,6.0,4.0,5.0],
3).collect::<Vec<(f64, f64)>>();