Function traquer::volume::elder_force
source · pub fn elder_force<'a>(
close: &'a [f64],
volume: &'a [f64],
window: usize,
) -> impl Iterator<Item = f64> + 'aExpand description
Elder Force Index
Calculated by multiplying the change in price by the volume traded during that period. A high EFI value indicates a strong price move with high volume, which can be a sign of a strong trend
Usage
A value above 0 suggests an uptrend.
Sources
Examples
use traquer::volume;
volume::elder_force(
&vec![1.0,2.0,3.0,4.0,5.0,6.0,4.0,5.0],
&vec![1.0,2.0,3.0,4.0,5.0,6.0,4.0,5.0],
6).collect::<Vec<f64>>();